@@ -7,17 +7,24 @@ defaultControl<-function() {
     soilFunctions = "SX",
     snowpack = TRUE,
     drainage = TRUE,
+    unlimitedSoilWater = FALSE,
+    plantWaterPools = FALSE,
+    poolOverlapFactor = 0.2,
     leafPhenology = TRUE,
     transpirationMode = "Granier", #vs. "Sperry"
-    hydraulicCostFunction = 1, #vs. 2
+    cuticularTranspiration = TRUE,
+    gainModifier = 1, 
+    costModifier = 1, 
     verticalLayerSize = 100,
-    nStemSegments = 1,
+    # nStemSegments = 1,
     capacitance = FALSE,
-    cavitationRefill = TRUE,
-    # ksymver = 0, # whole-stem symplastic vertical conductance
-    klat = 0.1, # symplastic-apoplastic lateral conductance
+    cavitationRefill = "total",
+    refillMaximumRate = 0.05,
+    klatstem = 0.01, # stem symplastic-apoplastic lateral conductance
+    klatleaf = 0.01, # leaf symplastic-apoplastic lateral conductance
     taper = TRUE,
     numericParams=list(maxNsteps = 400, ntrial = 200, psiTol = 0.0001, ETol = 0.0000001),
+    fracLeafResistance = NA,
     fracRootResistance = 0.4,
     averageFracRhizosphereResistance = 0.15,
     Catm = 386,
