@@ -19,7 +19,10 @@ double erFactor(int doy, double pet, double prec, double Rconv = 5.6, double Rsy
 
 double snowMelt(double tday, double rad, double LgroundSWR, double elevation);
 
-NumericVector verticalInputs(List soil, String soilFunctions, double prec, double er, double tday, double rad, double elevation,
-                             double Cm, double LgroundPAR, double LgroundSWR, 
-                             double runon = 0.0,
-                             bool snowpack = true, bool drainage = true, bool modifySoil = true);
+NumericVector soilWaterInputs(List soil, String soilFunctions, double prec, double er, double tday, double rad, double elevation,
+                              double Cm, double LgroundPAR, double LgroundSWR, 
+                              double runon = 0.0,
+                              bool snowpack = true, bool modifySoil = true);
+NumericVector soilInfiltrationPercolation(List soil, String soilFunctions, 
+                                          double waterInput,
+                                          bool drainage = true, bool modifySoil = true);
