@@ -11,7 +11,7 @@ double VmaxTemp(double Vmax298, double leaf_temp);
 double JmaxTemp(double Jmax298, double leaf_temp);
 
 DataFrame leafPhotosynthesisFunction(NumericVector E, double Catm, double Patm, double Tair, double vpa, double u, 
-                            double absRad, double Q, double Vmax298, double Jmax298, double Gwmin, double Gwmax, 
+                            double absRad, double Q, double Vmax298, double Jmax298, 
                             double leafWidth = 1.0, double refLeafArea = 1.0, bool verbose = false);
 
 DataFrame sunshadePhotosynthesisFunction(NumericVector E, double Catm, double Patm, double Tair, double vpa, 
@@ -20,12 +20,12 @@ DataFrame sunshadePhotosynthesisFunction(NumericVector E, double Catm, double Pa
                                     double QSL, double QSH, 
                                     double Vmax298SL, double Vmax298SH, 
                                     double Jmax298SL, double Jmax298SH, 
-                                    double Gwmin, double Gwmax, double leafWidth = 1.0, bool verbose = false);
+                                    double leafWidth = 1.0, bool verbose = false);
 
 DataFrame multilayerPhotosynthesisFunction(NumericVector E, double Catm, double Patm, double Tair, double vpa, 
                                   NumericVector SLarea, NumericVector SHarea,
                                   NumericVector u, NumericVector absRadSL, NumericVector absRadSH,
                                   NumericVector QSL, NumericVector QSH, 
                                   NumericVector Vmax298, NumericVector Jmax298, 
-                                  double Gwmin, double Gwmax, double leafWidth = 1.0, bool verbose = false);
+                                  double leafWidth = 1.0, bool verbose = false);
 
